[−][src]Module mop_structs::matrix::csr_matrix
CSR (Compressed Sparse Row) matrix.
See Wikipedia.
Structs
| CsrMatrix | This structure can hold differents mixed types of indexed storages. |
| CsrMatrixRowConstructor | Constructs a new valid row in a easy and interactive manner, abstracting away the complexity of the CSR format. |
| CsrMatrixRowIter | |
| CsrMatrixRowIterMut |
Type Definitions
| CsrMatrixArray | |
| CsrMatrixRef | |
| CsrMatrixVec | |
| CsrMatrixVecArray |